
WuttaWeb
========

This package provides a "web layer" for custom apps.

It uses traditional server-side rendering with VueJS on the front-end.

Good documentation and 100% `test coverage`_ are priorities for this
project.

.. _test coverage: https://buildbot.rattailproject.org/coverage/wuttaweb/

However as you can see..the API should be fairly well documented but
the narrative docs are pretty scant.  That will eventually change.

.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   glossary
   narr/cli/index
   narr/templates/index

.. toctree::
   :maxdepth: 1
   :caption: Package API:

   api/wuttaweb
   api/wuttaweb.app
   api/wuttaweb.auth
   api/wuttaweb.cli
   api/wuttaweb.cli.webapp
   api/wuttaweb.conf
   api/wuttaweb.db
   api/wuttaweb.db.continuum
   api/wuttaweb.db.sess
   api/wuttaweb.emails
   api/wuttaweb.forms
   api/wuttaweb.forms.base
   api/wuttaweb.forms.schema
   api/wuttaweb.forms.widgets
   api/wuttaweb.grids
   api/wuttaweb.grids.base
   api/wuttaweb.grids.filters
   api/wuttaweb.handler
   api/wuttaweb.helpers
   api/wuttaweb.menus
   api/wuttaweb.progress
   api/wuttaweb.static
   api/wuttaweb.subscribers
   api/wuttaweb.util
   api/wuttaweb.views
   api/wuttaweb.views.auth
   api/wuttaweb.views.base
   api/wuttaweb.views.batch
   api/wuttaweb.views.common
   api/wuttaweb.views.email
   api/wuttaweb.views.essential
   api/wuttaweb.views.master
   api/wuttaweb.views.people
   api/wuttaweb.views.progress
   api/wuttaweb.views.roles
   api/wuttaweb.views.settings
   api/wuttaweb.views.upgrades
   api/wuttaweb.views.users


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
